@@ -18,11 +18,16 @@ mod push;
 mod push_tags;
 mod rename_branch;
 mod reset;
+mod revision_files;
+mod revision_files_popup;
 mod stashmsg;
+mod syntax_text;
 mod tag_commit;
+mod taglist;
 mod textinput;
 mod utils;
 
+pub use self::filetree::FileTreeComponent;
 pub use blame_file::BlameFileComponent;
 pub use branchlist::BranchListComponent;
 pub use changes::ChangesComponent;
@@ -33,7 +38,6 @@ pub use commitlist::CommitList;
 pub use create_branch::CreateBranchComponent;
 pub use diff::DiffComponent;
 pub use externaleditor::ExternalEditorComponent;
-pub use filetree::FileTreeComponent;
 pub use help::HelpComponent;
 pub use inspect_commit::InspectCommitComponent;
 pub use msg::MsgComponent;
@@ -42,8 +46,12 @@ pub use push::PushComponent;
 pub use push_tags::PushTagsComponent;
 pub use rename_branch::RenameBranchComponent;
 pub use reset::ResetComponent;
+pub use revision_files::RevisionFilesComponent;
+pub use revision_files_popup::RevisionFilesPopup;
 pub use stashmsg::StashMsgComponent;
+pub use syntax_text::SyntaxTextComponent;
 pub use tag_commit::TagCommitComponent;
+pub use taglist::TagListComponent;
 pub use textinput::{InputType, TextInputComponent};
 pub use utils::filetree::FileTreeItemKind;
 
@@ -80,6 +88,50 @@ macro_rules! accessors {
     };
 }
 
+/// creates a function to determine if any popup is visible
+#[macro_export]
+macro_rules! any_popup_visible {
+    ($self:ident, [$($element:ident),+]) => {
+        fn any_popup_visible(& $self) -> bool{
+            ($($self.$element.is_visible()) || +)
+        }
+    };
+}
+
+/// creates the draw popup function
+#[macro_export]
+macro_rules! draw_popups {
+    ($self:ident, [$($element:ident),+]) => {
+        fn draw_popups<B: Backend>(& $self, mut f: &mut Frame<B>) -> Result<()>{
+            //TODO: move the layout part out and feed it into `draw_popups`
+            let size = Layout::default()
+            .direction(Direction::Vertical)
+            .constraints(
+                [
+                    Constraint::Min(1),
+                    Constraint::Length($self.cmdbar.borrow().height()),
+                ]
+                .as_ref(),
+            )
+            .split(f.size())[0];
+
+            ($($self.$element.draw(&mut f, size)?) , +);
+
+            return Ok(());
+        }
+    };
+}
+
+/// simply calls
+/// any_popup_visible!() and draw_popups!() macros
+#[macro_export]
+macro_rules! setup_popups {
+    ($self:ident, [$($element:ident),+]) => {
+        crate::any_popup_visible!($self, [$($element),+]);
+        crate::draw_popups!($self, [ $($element),+ ]);
+    };
+}
+
 /// returns `true` if event was consumed
 pub fn event_pump(
     ev: Event,
