@@ -12,7 +12,7 @@ use crate::{
 use anyhow::Result;
 use asyncgit::{
     sync::{self, CommitId, TreeFile},
-    AsyncNotification, CWD,
+    AsyncGitNotification, CWD,
 };
 use crossbeam_channel::Sender;
 use crossterm::event::Event;
@@ -52,7 +52,7 @@ impl RevisionFilesComponent {
     ///
     pub fn new(
         queue: &Queue,
-        sender: &Sender<AsyncNotification>,
+        sender: &Sender<AsyncGitNotification>,
         theme: SharedTheme,
         key_config: SharedKeyConfig,
     ) -> Self {
@@ -90,7 +90,7 @@ impl RevisionFilesComponent {
     }
 
     ///
-    pub fn update(&mut self, ev: AsyncNotification) {
+    pub fn update(&mut self, ev: AsyncGitNotification) {
         self.current_file.update(ev);
     }
 
@@ -130,14 +130,12 @@ impl RevisionFilesComponent {
 
     fn blame(&self) -> bool {
         self.tree.selected_file().map_or(false, |file| {
-            self.queue.borrow_mut().push_back(
-                InternalEvent::BlameFile(
-                    file.full_path_str()
-                        .strip_prefix("./")
-                        .unwrap_or_default()
-                        .to_string(),
-                ),
-            );
+            self.queue.push(InternalEvent::BlameFile(
+                file.full_path_str()
+                    .strip_prefix("./")
+                    .unwrap_or_default()
+                    .to_string(),
+            ));
             true
         })
     }
@@ -220,21 +218,22 @@ impl DrawableComponent for RevisionFilesComponent {
         f: &mut Frame<B>,
         area: Rect,
     ) -> Result<()> {
-        let chunks = Layout::default()
-            .direction(Direction::Horizontal)
-            .constraints(
-                [
-                    Constraint::Percentage(40),
-                    Constraint::Percentage(60),
-                ]
-                .as_ref(),
-            )
-            .split(area);
+        if self.is_visible() {
+            let chunks = Layout::default()
+                .direction(Direction::Horizontal)
+                .constraints(
+                    [
+                        Constraint::Percentage(40),
+                        Constraint::Percentage(60),
+                    ]
+                    .as_ref(),
+                )
+                .split(area);
 
-        self.draw_tree(f, chunks[0]);
-
-        self.current_file.draw(f, chunks[1])?;
+            self.draw_tree(f, chunks[0]);
 
+            self.current_file.draw(f, chunks[1])?;
+        }
         Ok(())
     }
 }
